@@ -1,6 +1,6 @@
 require(RUnit)
 require(gWidgets)
-options("guiToolkit"="tcltk")
+##options("guiToolkit"="tcltk")
 
 test.gcalendar <- function() {
   w <- gwindow()
